summaryrefslogtreecommitdiff
path: root/ridljar/source
diff options
context:
space:
mode:
authorSamuel Mehrbrodt <Samuel.Mehrbrodt@cib.de>2020-03-26 15:04:47 +0100
committerStephan Bergmann <sbergman@redhat.com>2020-05-06 14:48:21 +0200
commit35518c92365cc183ba6cce2a4d284a130c0ca13f (patch)
treef3de8bdec6331ce933126336cf701dcaffe9b662 /ridljar/source
parent6bf3517d60272bdec878bb6dde92a47b45a3f866 (diff)
Move all public Java classes to libreoffice.jar
This moves the classes from juh.jar and ridl.jar to libreoffice.jar The goal is to have one single jar (and Java module, will be added later) which developers can include to work with LO. juh.jar and ridl.jar are kept as basically empty jars with libreoffice.jar on its classpath to keep backwards compatibility. This is a continuation of ae855bf48163ff64d94cfc34aff8e37abdb5518d and a preparation to have Java 9 module support. Change-Id: Ifbbfb97f60373d14256e62ae3122913bd17d5bbb Reviewed-on: https://gerrit.libreoffice.org/c/core/+/91930 Tested-by: Jenkins Reviewed-by: Stephan Bergmann <sbergman@redhat.com>
Diffstat (limited to 'ridljar/source')
-rw-r--r--ridljar/source/libreoffice/manifest0
-rw-r--r--ridljar/source/unoloader/com/sun/star/lib/unoloader/UnoClassLoader.java9
-rw-r--r--ridljar/source/unoloader/com/sun/star/lib/unoloader/UnoLoader.java2
3 files changed, 5 insertions, 6 deletions
diff --git a/ridljar/source/libreoffice/manifest b/ridljar/source/libreoffice/manifest
new file mode 100644
index 000000000000..e69de29bb2d1
--- /dev/null
+++ b/ridljar/source/libreoffice/manifest
diff --git a/ridljar/source/unoloader/com/sun/star/lib/unoloader/UnoLoader.java b/ridljar/source/unoloader/com/sun/star/lib/unoloader/UnoLoader.java
index 1ed16fcca94c..23059b7b4cb5 100644
--- a/ridljar/source/unoloader/com/sun/star/lib/unoloader/UnoLoader.java
+++ b/ridljar/source/unoloader/com/sun/star/lib/unoloader/UnoLoader.java
@@ -38,7 +38,7 @@ public final class UnoLoader {
* Executes a UNO JAR.
*
* @param base a base URL relative to which the URE JARs
- * (<code>ridl.jar</code>, etc.) can be found; must
+ * (<code>libreoffice.jar</code>, etc.) can be found; must
* not be <code>null</code>.
*
* @param jar the URL of a UNO JAR that specifies a Main-Class; must not be
diff --git a/ridljar/source/unoloader/com/sun/star/lib/unoloader/UnoClassLoader.java b/ridljar/source/unoloader/com/sun/star/lib/unoloader/UnoClassLoader.java
index c52165abfeb7..822d1609cd3b 100644
--- a/ridljar/source/unoloader/com/sun/star/lib/unoloader/UnoClassLoader.java
+++ b/ridljar/source/unoloader/com/sun/star/lib/unoloader/UnoClassLoader.java
@@ -49,8 +49,8 @@ public final class UnoClassLoader extends URLClassLoader {
* Instantiates the root UNO class loader.
*
* @param base a base URL relative to which the URE JARs
* (<code>java_uno.jar</code>, <code>juh.jar</code>,
* <code>ridl.jar</code>) can be found; must not be <code>null</code>.
*
* @param classPath an array of URLs that form the class path of this class
* loader; may be <code>null</code>, which is the same as an empty array.
@@ -191,11 +191,10 @@ public final class UnoClassLoader extends URLClassLoader {
private static URL[] createUrls(URL base, URL[] classPath)
throws MalformedURLException
{
- final int JARS = 3;
+ final int JARS = 2;
URL[] urls = new URL[JARS + (classPath == null ? 0 : classPath.length)];
urls[0] = new URL(base, "java_uno.jar"); //TODO get rid of it here
- urls[1] = new URL(base, "juh.jar");
- urls[2] = new URL(base, "ridl.jar");
+ urls[1] = new URL(base, "libreoffice.jar");
if (classPath != null) {
System.arraycopy(classPath, 0, urls, JARS, classPath.length);
}
@@ -49,8 +49,8 @@ public final class UnoClassLoader extends URLClassLoader {
*
* @param base a base URL relative to which the URE JARs
- * (<code>java_uno.jar</code>, <code>juh.jar</code>,
- * <code>ridl.jar</code>) can be found; must not be <code>null</code>.
+ * (<code>java_uno.jar</code> and <code>libreoffice.jar</code>)
+ * can be found; must not be <code>null</code>.
*
* @param classPath an array of URLs that form the class path of this class